# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class UserResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'email': 'str',
        'phone_number': 'str',
        'application_role_code': 'ApplicationRoleCode',
        'is_approved': 'bool',
        'accepted_eula': 'bool',
        'last_login': 'datetime',
        'locked_out': 'bool',
        'corporations': 'list[UserCorporationChild]',
        'locations': 'list[UserLocationChild]'
    }

    attribute_map = {
        'id': 'Id',
        'first_name': 'FirstName',
        'last_name': 'LastName',
        'email': 'Email',
        'phone_number': 'PhoneNumber',
        'application_role_code': 'ApplicationRoleCode',
        'is_approved': 'IsApproved',
        'accepted_eula': 'AcceptedEula',
        'last_login': 'LastLogin',
        'locked_out': 'LockedOut',
        'corporations': 'Corporations',
        'locations': 'Locations'
    }

    def __init__(self, id=None, first_name=None, last_name=None, email=None, phone_number=None, application_role_code=None, is_approved=None, accepted_eula=None, last_login=None, locked_out=None, corporations=None, locations=None):  # noqa: E501
        """UserResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._first_name = None
        self._last_name = None
        self._email = None
        self._phone_number = None
        self._application_role_code = None
        self._is_approved = None
        self._accepted_eula = None
        self._last_login = None
        self._locked_out = None
        self._corporations = None
        self._locations = None
        self.discriminator = None
        self.id = id
        self.first_name = first_name
        self.last_name = last_name
        self.email = email
        if phone_number is not None:
            self.phone_number = phone_number
        self.application_role_code = application_role_code
        self.is_approved = is_approved
        self.accepted_eula = accepted_eula
        if last_login is not None:
            self.last_login = last_login
        self.locked_out = locked_out
        self.corporations = corporations
        self.locations = locations

    @property
    def id(self):
        """Gets the id of this UserResponse.  # noqa: E501


        :return: The id of this UserResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UserResponse.


        :param id: The id of this UserResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def first_name(self):
        """Gets the first_name of this UserResponse.  # noqa: E501


        :return: The first_name of this UserResponse.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this UserResponse.


        :param first_name: The first_name of this UserResponse.  # noqa: E501
        :type: str
        """
        if first_name is None:
            raise ValueError("Invalid value for `first_name`, must not be `None`")  # noqa: E501

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this UserResponse.  # noqa: E501


        :return: The last_name of this UserResponse.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this UserResponse.


        :param last_name: The last_name of this UserResponse.  # noqa: E501
        :type: str
        """
        if last_name is None:
            raise ValueError("Invalid value for `last_name`, must not be `None`")  # noqa: E501

        self._last_name = last_name

    @property
    def email(self):
        """Gets the email of this UserResponse.  # noqa: E501


        :return: The email of this UserResponse.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this UserResponse.


        :param email: The email of this UserResponse.  # noqa: E501
        :type: str
        """
        if email is None:
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    @property
    def phone_number(self):
        """Gets the phone_number of this UserResponse.  # noqa: E501


        :return: The phone_number of this UserResponse.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this UserResponse.


        :param phone_number: The phone_number of this UserResponse.  # noqa: E501
        :type: str
        """

        self._phone_number = phone_number

    @property
    def application_role_code(self):
        """Gets the application_role_code of this UserResponse.  # noqa: E501


        :return: The application_role_code of this UserResponse.  # noqa: E501
        :rtype: ApplicationRoleCode
        """
        return self._application_role_code

    @application_role_code.setter
    def application_role_code(self, application_role_code):
        """Sets the application_role_code of this UserResponse.


        :param application_role_code: The application_role_code of this UserResponse.  # noqa: E501
        :type: ApplicationRoleCode
        """
        if application_role_code is None:
            raise ValueError("Invalid value for `application_role_code`, must not be `None`")  # noqa: E501

        self._application_role_code = application_role_code

    @property
    def is_approved(self):
        """Gets the is_approved of this UserResponse.  # noqa: E501


        :return: The is_approved of this UserResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_approved

    @is_approved.setter
    def is_approved(self, is_approved):
        """Sets the is_approved of this UserResponse.


        :param is_approved: The is_approved of this UserResponse.  # noqa: E501
        :type: bool
        """
        if is_approved is None:
            raise ValueError("Invalid value for `is_approved`, must not be `None`")  # noqa: E501

        self._is_approved = is_approved

    @property
    def accepted_eula(self):
        """Gets the accepted_eula of this UserResponse.  # noqa: E501


        :return: The accepted_eula of this UserResponse.  # noqa: E501
        :rtype: bool
        """
        return self._accepted_eula

    @accepted_eula.setter
    def accepted_eula(self, accepted_eula):
        """Sets the accepted_eula of this UserResponse.


        :param accepted_eula: The accepted_eula of this UserResponse.  # noqa: E501
        :type: bool
        """
        if accepted_eula is None:
            raise ValueError("Invalid value for `accepted_eula`, must not be `None`")  # noqa: E501

        self._accepted_eula = accepted_eula

    @property
    def last_login(self):
        """Gets the last_login of this UserResponse.  # noqa: E501


        :return: The last_login of this UserResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._last_login

    @last_login.setter
    def last_login(self, last_login):
        """Sets the last_login of this UserResponse.


        :param last_login: The last_login of this UserResponse.  # noqa: E501
        :type: datetime
        """

        self._last_login = last_login

    @property
    def locked_out(self):
        """Gets the locked_out of this UserResponse.  # noqa: E501

        This is only relevant to non-SSO users, even if it is {true}  # noqa: E501

        :return: The locked_out of this UserResponse.  # noqa: E501
        :rtype: bool
        """
        return self._locked_out

    @locked_out.setter
    def locked_out(self, locked_out):
        """Sets the locked_out of this UserResponse.

        This is only relevant to non-SSO users, even if it is {true}  # noqa: E501

        :param locked_out: The locked_out of this UserResponse.  # noqa: E501
        :type: bool
        """
        if locked_out is None:
            raise ValueError("Invalid value for `locked_out`, must not be `None`")  # noqa: E501

        self._locked_out = locked_out

    @property
    def corporations(self):
        """Gets the corporations of this UserResponse.  # noqa: E501


        :return: The corporations of this UserResponse.  # noqa: E501
        :rtype: list[UserCorporationChild]
        """
        return self._corporations

    @corporations.setter
    def corporations(self, corporations):
        """Sets the corporations of this UserResponse.


        :param corporations: The corporations of this UserResponse.  # noqa: E501
        :type: list[UserCorporationChild]
        """
        if corporations is None:
            raise ValueError("Invalid value for `corporations`, must not be `None`")  # noqa: E501

        self._corporations = corporations

    @property
    def locations(self):
        """Gets the locations of this UserResponse.  # noqa: E501


        :return: The locations of this UserResponse.  # noqa: E501
        :rtype: list[UserLocationChild]
        """
        return self._locations

    @locations.setter
    def locations(self, locations):
        """Sets the locations of this UserResponse.


        :param locations: The locations of this UserResponse.  # noqa: E501
        :type: list[UserLocationChild]
        """
        if locations is None:
            raise ValueError("Invalid value for `locations`, must not be `None`")  # noqa: E501

        self._locations = locations

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UserResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from smart_diagnostics_client.api_client import ApiClient


class GroupsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_analytics_model_to_group(self, group_id, **kwargs):  # noqa: E501
        """Add Analytics Models to a Group  # noqa: E501

        Required Permissions: System Admin / Sentry  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_analytics_model_to_group(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: (required)
        :param GroupAnalyticsModelAddRequest body:
        :return: GroupAnalyticsModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_analytics_model_to_group_with_http_info(group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.add_analytics_model_to_group_with_http_info(group_id, **kwargs)  # noqa: E501
            return data

    def add_analytics_model_to_group_with_http_info(self, group_id, **kwargs):  # noqa: E501
        """Add Analytics Models to a Group  # noqa: E501

        Required Permissions: System Admin / Sentry  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_analytics_model_to_group_with_http_info(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: (required)
        :param GroupAnalyticsModelAddRequest body:
        :return: GroupAnalyticsModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_analytics_model_to_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_id' is set
        if ('group_id' not in params or
                params['group_id'] is None):
            raise ValueError("Missing the required parameter `group_id` when calling `add_analytics_model_to_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Groups/{groupId}/Analytics/Models', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GroupAnalyticsModelResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_spectrum_chart_settings(self, group_id, **kwargs):  # noqa: E501
        """Creates the Spectrum Chart settings for a group  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_spectrum_chart_settings(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: (required)
        :param SpectrumChartSettingsCreateRequest body: Contains chart setting info for the Frequency and Time Domains
        :return: SpectrumChartSettingsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_spectrum_chart_settings_with_http_info(group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.create_spectrum_chart_settings_with_http_info(group_id, **kwargs)  # noqa: E501
            return data

    def create_spectrum_chart_settings_with_http_info(self, group_id, **kwargs):  # noqa: E501
        """Creates the Spectrum Chart settings for a group  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_spectrum_chart_settings_with_http_info(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: (required)
        :param SpectrumChartSettingsCreateRequest body: Contains chart setting info for the Frequency and Time Domains
        :return: SpectrumChartSettingsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_spectrum_chart_settings" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_id' is set
        if ('group_id' not in params or
                params['group_id'] is None):
            raise ValueError("Missing the required parameter `group_id` when calling `create_spectrum_chart_settings`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Groups/{groupId}/spectrumChartSettings', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SpectrumChartSettingsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_analytics_model_from_group(self, group_id, model_id, **kwargs):  # noqa: E501
        """Deletes an Analytics Model from group  # noqa: E501

        Required Permissions: System Admin / Sentry  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_analytics_model_from_group(group_id, model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: Group form which to remove the model (required)
        :param str model_id: ID of the model to be removed (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_analytics_model_from_group_with_http_info(group_id, model_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_analytics_model_from_group_with_http_info(group_id, model_id, **kwargs)  # noqa: E501
            return data

    def delete_analytics_model_from_group_with_http_info(self, group_id, model_id, **kwargs):  # noqa: E501
        """Deletes an Analytics Model from group  # noqa: E501

        Required Permissions: System Admin / Sentry  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_analytics_model_from_group_with_http_info(group_id, model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: Group form which to remove the model (required)
        :param str model_id: ID of the model to be removed (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id', 'model_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_analytics_model_from_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_id' is set
        if ('group_id' not in params or
                params['group_id'] is None):
            raise ValueError("Missing the required parameter `group_id` when calling `delete_analytics_model_from_group`")  # noqa: E501
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params or
                params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `delete_analytics_model_from_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']  # noqa: E501
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Groups/{groupId}/Analytics/Models/{modelId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_bearings_for_group(self, group_id, **kwargs):  # noqa: E501
        """Gets all bearings for a group  # noqa: E501

        Required Permissions: User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_bearings_for_group(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: (required)
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Manufacturer` | String | `eq, neq, like, in` | | `Name` | String | `eq, neq, like, in` | | `RollerCount` | Int64 | `eq, neq, in, lt, gt, leq, geq` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Bpfi` | Double | | `Bpfo` | Double | | `Bsf` | Double | | `Ftf` | Double | | `Manufacturer` | String | | `Name` | String | | `RollerCount` | Int64 |
        :return: PagedResultsModelBearingResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_bearings_for_group_with_http_info(group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_bearings_for_group_with_http_info(group_id, **kwargs)  # noqa: E501
            return data

    def get_bearings_for_group_with_http_info(self, group_id, **kwargs):  # noqa: E501
        """Gets all bearings for a group  # noqa: E501

        Required Permissions: User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_bearings_for_group_with_http_info(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: (required)
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Manufacturer` | String | `eq, neq, like, in` | | `Name` | String | `eq, neq, like, in` | | `RollerCount` | Int64 | `eq, neq, in, lt, gt, leq, geq` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Bpfi` | Double | | `Bpfo` | Double | | `Bsf` | Double | | `Ftf` | Double | | `Manufacturer` | String | | `Name` | String | | `RollerCount` | Int64 |
        :return: PagedResultsModelBearingResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id', 'filter', 'page', 'page_limit', 'order_by']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_bearings_for_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_id' is set
        if ('group_id' not in params or
                params['group_id'] is None):
            raise ValueError("Missing the required parameter `group_id` when calling `get_bearings_for_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']  # noqa: E501

        query_params = []
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Groups/{groupId}/bearings', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelBearingResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_group_alerts(self, group_id, **kwargs):  # noqa: E501
        """Gets the alerts for the given group  # noqa: E501

        Required Permissions:  User must have access to the Group  User must have access to the Filters  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_group_alerts(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: The group to get the alerts for (required)
        :param list[str] filter_ids:
        :param str sensor_role_type: SensorRoleType is an additional filtering component for limiting to X or Y.
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `IndicatorName` | String | | `IndicatorSortOrder` | Int32? | | `TimeOfAlert` | DateTime? |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: None.
        :return: PagedResultsModelGroupAlertsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_group_alerts_with_http_info(group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_group_alerts_with_http_info(group_id, **kwargs)  # noqa: E501
            return data

    def get_group_alerts_with_http_info(self, group_id, **kwargs):  # noqa: E501
        """Gets the alerts for the given group  # noqa: E501

        Required Permissions:  User must have access to the Group  User must have access to the Filters  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_group_alerts_with_http_info(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: The group to get the alerts for (required)
        :param list[str] filter_ids:
        :param str sensor_role_type: SensorRoleType is an additional filtering component for limiting to X or Y.
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `IndicatorName` | String | | `IndicatorSortOrder` | Int32? | | `TimeOfAlert` | DateTime? |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: None.
        :return: PagedResultsModelGroupAlertsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id', 'filter_ids', 'sensor_role_type', 'page', 'page_limit', 'order_by', 'name_search']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_group_alerts" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_id' is set
        if ('group_id' not in params or
                params['group_id'] is None):
            raise ValueError("Missing the required parameter `group_id` when calling `get_group_alerts`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']  # noqa: E501

        query_params = []
        if 'filter_ids' in params:
            query_params.append(('FilterIds', params['filter_ids']))  # noqa: E501
            collection_formats['FilterIds'] = 'multi'  # noqa: E501
        if 'sensor_role_type' in params:
            query_params.append(('SensorRoleType', params['sensor_role_type']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501
        if 'name_search' in params:
            query_params.append(('NameSearch', params['name_search']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Groups/{groupId}/alerts', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelGroupAlertsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_group_analytics_model(self, group_id, model_id, **kwargs):  # noqa: E501
        """Gets a Group Analytics Model  # noqa: E501

        Required Permissions: System Admin / Sentry  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_group_analytics_model(group_id, model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: (required)
        :param str model_id: (required)
        :return: GroupAnalyticsModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_group_analytics_model_with_http_info(group_id, model_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_group_analytics_model_with_http_info(group_id, model_id, **kwargs)  # noqa: E501
            return data

    def get_group_analytics_model_with_http_info(self, group_id, model_id, **kwargs):  # noqa: E501
        """Gets a Group Analytics Model  # noqa: E501

        Required Permissions: System Admin / Sentry  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_group_analytics_model_with_http_info(group_id, model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: (required)
        :param str model_id: (required)
        :return: GroupAnalyticsModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id', 'model_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_group_analytics_model" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_id' is set
        if ('group_id' not in params or
                params['group_id'] is None):
            raise ValueError("Missing the required parameter `group_id` when calling `get_group_analytics_model`")  # noqa: E501
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params or
                params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `get_group_analytics_model`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']  # noqa: E501
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Groups/{groupId}/Analytics/Models/{modelId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GroupAnalyticsModelResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_group_analytics_models(self, **kwargs):  # noqa: E501
        """Gets Analytics Models assigned to a group  # noqa: E501

        Required Permissions: System Admin / Sentry  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_group_analytics_models(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] location_ids: A list of location ids to filter the results to models that are assigned to them or are global
        :param list[str] corporation_ids: A list of corporation ids to filter the results to models that are assigned to them or are global. This will only return corporation-based or global models. To view location-based models, provide the location id in locationIds.
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `CorporationAbbreviation` | String | `eq, neq, like, in` | | `CorporationId` | Guid | `eq, neq, in` | | `CorporationName` | String | `eq, neq, like, in` | | `Created` | DateTime | `eq, neq, in, lt, gt, leq, geq` | | `ErrorType` | AnalyticsModelErrorTypeCodes? | `eq, neq, in` | | `GroupType` | GroupTypeCodes | `eq, neq, in` | | `IsDeprecated` | Boolean | `eq, neq` | | `IsGlobal` | Boolean | `eq, neq` | | `LocationAbbreviation` | String | `eq, neq, like, in` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, like, in` | | `Name` | String | `eq, neq, like, in` | | `Version` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Created` | DateTime | | `GroupName` | String | | `Name` | String | | `Version` | String |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `GroupName`, `Name`.
        :return: PagedResultsModelGroupAnalyticsModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_group_analytics_models_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_group_analytics_models_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_group_analytics_models_with_http_info(self, **kwargs):  # noqa: E501
        """Gets Analytics Models assigned to a group  # noqa: E501

        Required Permissions: System Admin / Sentry  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_group_analytics_models_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] location_ids: A list of location ids to filter the results to models that are assigned to them or are global
        :param list[str] corporation_ids: A list of corporation ids to filter the results to models that are assigned to them or are global. This will only return corporation-based or global models. To view location-based models, provide the location id in locationIds.
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `CorporationAbbreviation` | String | `eq, neq, like, in` | | `CorporationId` | Guid | `eq, neq, in` | | `CorporationName` | String | `eq, neq, like, in` | | `Created` | DateTime | `eq, neq, in, lt, gt, leq, geq` | | `ErrorType` | AnalyticsModelErrorTypeCodes? | `eq, neq, in` | | `GroupType` | GroupTypeCodes | `eq, neq, in` | | `IsDeprecated` | Boolean | `eq, neq` | | `IsGlobal` | Boolean | `eq, neq` | | `LocationAbbreviation` | String | `eq, neq, like, in` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, like, in` | | `Name` | String | `eq, neq, like, in` | | `Version` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Created` | DateTime | | `GroupName` | String | | `Name` | String | | `Version` | String |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `GroupName`, `Name`.
        :return: PagedResultsModelGroupAnalyticsModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['location_ids', 'corporation_ids', 'filter', 'page', 'page_limit', 'order_by', 'name_search']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_group_analytics_models" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'location_ids' in params:
            query_params.append(('locationIds', params['location_ids']))  # noqa: E501
            collection_formats['locationIds'] = 'multi'  # noqa: E501
        if 'corporation_ids' in params:
            query_params.append(('corporationIds', params['corporation_ids']))  # noqa: E501
            collection_formats['corporationIds'] = 'multi'  # noqa: E501
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501
        if 'name_search' in params:
            query_params.append(('NameSearch', params['name_search']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Groups/Analytics/Models', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelGroupAnalyticsModelResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_group_analytics_models_for_group(self, group_id, **kwargs):  # noqa: E501
        """Gets Analytics Models assigned to a specific group  # noqa: E501

        Required Permissions: System Admin / Sentry  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_group_analytics_models_for_group(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: GroupId from which to obtain assigned analytic models. (required)
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `CorporationAbbreviation` | String | `eq, neq, like, in` | | `CorporationId` | Guid | `eq, neq, in` | | `CorporationName` | String | `eq, neq, like, in` | | `Created` | DateTime | `eq, neq, in, lt, gt, leq, geq` | | `ErrorType` | AnalyticsModelErrorTypeCodes? | `eq, neq, in` | | `GroupType` | GroupTypeCodes | `eq, neq, in` | | `IsDeprecated` | Boolean | `eq, neq` | | `IsGlobal` | Boolean | `eq, neq` | | `LocationAbbreviation` | String | `eq, neq, like, in` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, like, in` | | `Name` | String | `eq, neq, like, in` | | `Version` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Created` | DateTime | | `GroupName` | String | | `Name` | String | | `Version` | String |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `GroupName`, `Name`.
        :return: PagedResultsModelGroupAnalyticsModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_group_analytics_models_for_group_with_http_info(group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_group_analytics_models_for_group_with_http_info(group_id, **kwargs)  # noqa: E501
            return data

    def get_group_analytics_models_for_group_with_http_info(self, group_id, **kwargs):  # noqa: E501
        """Gets Analytics Models assigned to a specific group  # noqa: E501

        Required Permissions: System Admin / Sentry  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_group_analytics_models_for_group_with_http_info(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: GroupId from which to obtain assigned analytic models. (required)
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `CorporationAbbreviation` | String | `eq, neq, like, in` | | `CorporationId` | Guid | `eq, neq, in` | | `CorporationName` | String | `eq, neq, like, in` | | `Created` | DateTime | `eq, neq, in, lt, gt, leq, geq` | | `ErrorType` | AnalyticsModelErrorTypeCodes? | `eq, neq, in` | | `GroupType` | GroupTypeCodes | `eq, neq, in` | | `IsDeprecated` | Boolean | `eq, neq` | | `IsGlobal` | Boolean | `eq, neq` | | `LocationAbbreviation` | String | `eq, neq, like, in` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, like, in` | | `Name` | String | `eq, neq, like, in` | | `Version` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Created` | DateTime | | `GroupName` | String | | `Name` | String | | `Version` | String |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `GroupName`, `Name`.
        :return: PagedResultsModelGroupAnalyticsModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id', 'filter', 'page', 'page_limit', 'order_by', 'name_search']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_group_analytics_models_for_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_id' is set
        if ('group_id' not in params or
                params['group_id'] is None):
            raise ValueError("Missing the required parameter `group_id` when calling `get_group_analytics_models_for_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']  # noqa: E501

        query_params = []
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501
        if 'name_search' in params:
            query_params.append(('NameSearch', params['name_search']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Groups/{groupId}/Analytics/Models', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelGroupAnalyticsModelResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_monitoring_point_overview_obsolete(self, group_id, **kwargs):  # noqa: E501
        """Gets an overview of monitoring point(s) which includes the node settings  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_monitoring_point_overview_obsolete(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: (required)
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `HierarchyAbbreviation` | String | `eq, neq, like, in` | | `HierarchyName` | String | `eq, neq, like, in` | | `MonitoringPointType` | MonitoringPointTypeCodes | `eq, neq, in` | | `Name` | String | `eq, neq, like, in` | | `NodeNickname` | String | `eq, neq, like, in` | | `NodeSerialNumber` | String | `eq, neq, like, in` | | `RunningSpeedMultiplier` | Double? | `eq, neq, in, lt, gt, leq, geq` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `DecimationFactor` | NodeSettingValues | | `HierarchyAbbreviation` | String | | `HierarchyName` | String | | `MonitoringPointType` | MonitoringPointTypeCodes | | `Name` | String | | `NodeNickname` | String | | `NodeSerialNumber` | String | | `RunningSpeedMultiplier` | Double? | | `UpdateInterval` | NodeSettingValues |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `HierarchySearch`, `NodeNickname`, `NodeSerialNumber`.
        :return: PagedResultsModelMonitoringPointOverviewResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_monitoring_point_overview_obsolete_with_http_info(group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_monitoring_point_overview_obsolete_with_http_info(group_id, **kwargs)  # noqa: E501
            return data

    def get_monitoring_point_overview_obsolete_with_http_info(self, group_id, **kwargs):  # noqa: E501
        """Gets an overview of monitoring point(s) which includes the node settings  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_monitoring_point_overview_obsolete_with_http_info(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: (required)
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `HierarchyAbbreviation` | String | `eq, neq, like, in` | | `HierarchyName` | String | `eq, neq, like, in` | | `MonitoringPointType` | MonitoringPointTypeCodes | `eq, neq, in` | | `Name` | String | `eq, neq, like, in` | | `NodeNickname` | String | `eq, neq, like, in` | | `NodeSerialNumber` | String | `eq, neq, like, in` | | `RunningSpeedMultiplier` | Double? | `eq, neq, in, lt, gt, leq, geq` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `DecimationFactor` | NodeSettingValues | | `HierarchyAbbreviation` | String | | `HierarchyName` | String | | `MonitoringPointType` | MonitoringPointTypeCodes | | `Name` | String | | `NodeNickname` | String | | `NodeSerialNumber` | String | | `RunningSpeedMultiplier` | Double? | | `UpdateInterval` | NodeSettingValues |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `HierarchySearch`, `NodeNickname`, `NodeSerialNumber`.
        :return: PagedResultsModelMonitoringPointOverviewResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id', 'filter', 'page', 'page_limit', 'order_by', 'name_search']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_monitoring_point_overview_obsolete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_id' is set
        if ('group_id' not in params or
                params['group_id'] is None):
            raise ValueError("Missing the required parameter `group_id` when calling `get_monitoring_point_overview_obsolete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']  # noqa: E501

        query_params = []
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501
        if 'name_search' in params:
            query_params.append(('NameSearch', params['name_search']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Groups/{groupId}/monitoringPoints/overview', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelMonitoringPointOverviewResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_spectrum_chart_settings(self, group_id, **kwargs):  # noqa: E501
        """Gets the Spectrum Chart Settings for a given group  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_spectrum_chart_settings(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: The group to retrieve the spectrum chart settings for (required)
        :return: SpectrumChartSettingsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_spectrum_chart_settings_with_http_info(group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_spectrum_chart_settings_with_http_info(group_id, **kwargs)  # noqa: E501
            return data

    def get_spectrum_chart_settings_with_http_info(self, group_id, **kwargs):  # noqa: E501
        """Gets the Spectrum Chart Settings for a given group  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_spectrum_chart_settings_with_http_info(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: The group to retrieve the spectrum chart settings for (required)
        :return: SpectrumChartSettingsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_spectrum_chart_settings" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_id' is set
        if ('group_id' not in params or
                params['group_id'] is None):
            raise ValueError("Missing the required parameter `group_id` when calling `get_spectrum_chart_settings`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Groups/{groupId}/spectrumChartSettings', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SpectrumChartSettingsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_analytics_model_on_group(self, group_id, model_id, **kwargs):  # noqa: E501
        """Updates Analytics Models for a Group  # noqa: E501

        Required Permissions: System Admin / Sentry  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_analytics_model_on_group(group_id, model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: (required)
        :param str model_id: (required)
        :param GroupAnalyticsModelUpdateRequest body:
        :return: GroupAnalyticsModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_analytics_model_on_group_with_http_info(group_id, model_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_analytics_model_on_group_with_http_info(group_id, model_id, **kwargs)  # noqa: E501
            return data

    def update_analytics_model_on_group_with_http_info(self, group_id, model_id, **kwargs):  # noqa: E501
        """Updates Analytics Models for a Group  # noqa: E501

        Required Permissions: System Admin / Sentry  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_analytics_model_on_group_with_http_info(group_id, model_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: (required)
        :param str model_id: (required)
        :param GroupAnalyticsModelUpdateRequest body:
        :return: GroupAnalyticsModelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id', 'model_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_analytics_model_on_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_id' is set
        if ('group_id' not in params or
                params['group_id'] is None):
            raise ValueError("Missing the required parameter `group_id` when calling `update_analytics_model_on_group`")  # noqa: E501
        # verify the required parameter 'model_id' is set
        if ('model_id' not in params or
                params['model_id'] is None):
            raise ValueError("Missing the required parameter `model_id` when calling `update_analytics_model_on_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']  # noqa: E501
        if 'model_id' in params:
            path_params['modelId'] = params['model_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Groups/{groupId}/Analytics/Models/{modelId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GroupAnalyticsModelResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_bearings_for_group(self, group_id, **kwargs):  # noqa: E501
        """Updates bearings for a group  # noqa: E501

        Required Permissions: User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_bearings_for_group(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: (required)
        :param UpdateBearingsForGroupRequest body:
        :return: list[BearingResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_bearings_for_group_with_http_info(group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_bearings_for_group_with_http_info(group_id, **kwargs)  # noqa: E501
            return data

    def update_bearings_for_group_with_http_info(self, group_id, **kwargs):  # noqa: E501
        """Updates bearings for a group  # noqa: E501

        Required Permissions: User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_bearings_for_group_with_http_info(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: (required)
        :param UpdateBearingsForGroupRequest body:
        :return: list[BearingResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_bearings_for_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_id' is set
        if ('group_id' not in params or
                params['group_id'] is None):
            raise ValueError("Missing the required parameter `group_id` when calling `update_bearings_for_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Groups/{groupId}/bearings', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[BearingResponse]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class LocationSettingsChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'max_transport_interval': 'int',
        'max_vibration_update_interval': 'int',
        'max_oil_quality_update_interval': 'int',
        'opc_enabled': 'bool',
        'assign_filters_to_location': 'bool',
        'external_notification_type': 'ExternalNotificationType'
    }

    attribute_map = {
        'max_transport_interval': 'MaxTransportInterval',
        'max_vibration_update_interval': 'MaxVibrationUpdateInterval',
        'max_oil_quality_update_interval': 'MaxOilQualityUpdateInterval',
        'opc_enabled': 'OpcEnabled',
        'assign_filters_to_location': 'AssignFiltersToLocation',
        'external_notification_type': 'ExternalNotificationType'
    }

    def __init__(self, max_transport_interval=None, max_vibration_update_interval=None, max_oil_quality_update_interval=None, opc_enabled=None, assign_filters_to_location=None, external_notification_type=None):  # noqa: E501
        """LocationSettingsChild - a model defined in Swagger"""  # noqa: E501
        self._max_transport_interval = None
        self._max_vibration_update_interval = None
        self._max_oil_quality_update_interval = None
        self._opc_enabled = None
        self._assign_filters_to_location = None
        self._external_notification_type = None
        self.discriminator = None
        if max_transport_interval is not None:
            self.max_transport_interval = max_transport_interval
        if max_vibration_update_interval is not None:
            self.max_vibration_update_interval = max_vibration_update_interval
        if max_oil_quality_update_interval is not None:
            self.max_oil_quality_update_interval = max_oil_quality_update_interval
        if opc_enabled is not None:
            self.opc_enabled = opc_enabled
        if assign_filters_to_location is not None:
            self.assign_filters_to_location = assign_filters_to_location
        if external_notification_type is not None:
            self.external_notification_type = external_notification_type

    @property
    def max_transport_interval(self):
        """Gets the max_transport_interval of this LocationSettingsChild.  # noqa: E501


        :return: The max_transport_interval of this LocationSettingsChild.  # noqa: E501
        :rtype: int
        """
        return self._max_transport_interval

    @max_transport_interval.setter
    def max_transport_interval(self, max_transport_interval):
        """Sets the max_transport_interval of this LocationSettingsChild.


        :param max_transport_interval: The max_transport_interval of this LocationSettingsChild.  # noqa: E501
        :type: int
        """

        self._max_transport_interval = max_transport_interval

    @property
    def max_vibration_update_interval(self):
        """Gets the max_vibration_update_interval of this LocationSettingsChild.  # noqa: E501


        :return: The max_vibration_update_interval of this LocationSettingsChild.  # noqa: E501
        :rtype: int
        """
        return self._max_vibration_update_interval

    @max_vibration_update_interval.setter
    def max_vibration_update_interval(self, max_vibration_update_interval):
        """Sets the max_vibration_update_interval of this LocationSettingsChild.


        :param max_vibration_update_interval: The max_vibration_update_interval of this LocationSettingsChild.  # noqa: E501
        :type: int
        """

        self._max_vibration_update_interval = max_vibration_update_interval

    @property
    def max_oil_quality_update_interval(self):
        """Gets the max_oil_quality_update_interval of this LocationSettingsChild.  # noqa: E501


        :return: The max_oil_quality_update_interval of this LocationSettingsChild.  # noqa: E501
        :rtype: int
        """
        return self._max_oil_quality_update_interval

    @max_oil_quality_update_interval.setter
    def max_oil_quality_update_interval(self, max_oil_quality_update_interval):
        """Sets the max_oil_quality_update_interval of this LocationSettingsChild.


        :param max_oil_quality_update_interval: The max_oil_quality_update_interval of this LocationSettingsChild.  # noqa: E501
        :type: int
        """

        self._max_oil_quality_update_interval = max_oil_quality_update_interval

    @property
    def opc_enabled(self):
        """Gets the opc_enabled of this LocationSettingsChild.  # noqa: E501


        :return: The opc_enabled of this LocationSettingsChild.  # noqa: E501
        :rtype: bool
        """
        return self._opc_enabled

    @opc_enabled.setter
    def opc_enabled(self, opc_enabled):
        """Sets the opc_enabled of this LocationSettingsChild.


        :param opc_enabled: The opc_enabled of this LocationSettingsChild.  # noqa: E501
        :type: bool
        """

        self._opc_enabled = opc_enabled

    @property
    def assign_filters_to_location(self):
        """Gets the assign_filters_to_location of this LocationSettingsChild.  # noqa: E501


        :return: The assign_filters_to_location of this LocationSettingsChild.  # noqa: E501
        :rtype: bool
        """
        return self._assign_filters_to_location

    @assign_filters_to_location.setter
    def assign_filters_to_location(self, assign_filters_to_location):
        """Sets the assign_filters_to_location of this LocationSettingsChild.


        :param assign_filters_to_location: The assign_filters_to_location of this LocationSettingsChild.  # noqa: E501
        :type: bool
        """

        self._assign_filters_to_location = assign_filters_to_location

    @property
    def external_notification_type(self):
        """Gets the external_notification_type of this LocationSettingsChild.  # noqa: E501


        :return: The external_notification_type of this LocationSettingsChild.  # noqa: E501
        :rtype: ExternalNotificationType
        """
        return self._external_notification_type

    @external_notification_type.setter
    def external_notification_type(self, external_notification_type):
        """Sets the external_notification_type of this LocationSettingsChild.


        :param external_notification_type: The external_notification_type of this LocationSettingsChild.  # noqa: E501
        :type: ExternalNotificationType
        """

        self._external_notification_type = external_notification_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LocationSettingsChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LocationSettingsChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class IndicatorGroupResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'parent': 'ParentChild',
        'hierarchy': 'list[HierarchyChild]',
        'id': 'str',
        'name': 'str',
        'abbreviation': 'str',
        'active': 'bool',
        'is_paused': 'bool',
        'is_snoozed': 'bool',
        'created': 'datetime',
        'corporation': 'CorporationChild',
        'location': 'LocationChild'
    }

    attribute_map = {
        'parent': 'Parent',
        'hierarchy': 'Hierarchy',
        'id': 'Id',
        'name': 'Name',
        'abbreviation': 'Abbreviation',
        'active': 'Active',
        'is_paused': 'IsPaused',
        'is_snoozed': 'IsSnoozed',
        'created': 'Created',
        'corporation': 'Corporation',
        'location': 'Location'
    }

    def __init__(self, parent=None, hierarchy=None, id=None, name=None, abbreviation=None, active=None, is_paused=None, is_snoozed=None, created=None, corporation=None, location=None):  # noqa: E501
        """IndicatorGroupResponse - a model defined in Swagger"""  # noqa: E501
        self._parent = None
        self._hierarchy = None
        self._id = None
        self._name = None
        self._abbreviation = None
        self._active = None
        self._is_paused = None
        self._is_snoozed = None
        self._created = None
        self._corporation = None
        self._location = None
        self.discriminator = None
        if parent is not None:
            self.parent = parent
        if hierarchy is not None:
            self.hierarchy = hierarchy
        self.id = id
        self.name = name
        if abbreviation is not None:
            self.abbreviation = abbreviation
        self.active = active
        self.is_paused = is_paused
        self.is_snoozed = is_snoozed
        self.created = created
        self.corporation = corporation
        self.location = location

    @property
    def parent(self):
        """Gets the parent of this IndicatorGroupResponse.  # noqa: E501


        :return: The parent of this IndicatorGroupResponse.  # noqa: E501
        :rtype: ParentChild
        """
        return self._parent

    @parent.setter
    def parent(self, parent):
        """Sets the parent of this IndicatorGroupResponse.


        :param parent: The parent of this IndicatorGroupResponse.  # noqa: E501
        :type: ParentChild
        """

        self._parent = parent

    @property
    def hierarchy(self):
        """Gets the hierarchy of this IndicatorGroupResponse.  # noqa: E501


        :return: The hierarchy of this IndicatorGroupResponse.  # noqa: E501
        :rtype: list[HierarchyChild]
        """
        return self._hierarchy

    @hierarchy.setter
    def hierarchy(self, hierarchy):
        """Sets the hierarchy of this IndicatorGroupResponse.


        :param hierarchy: The hierarchy of this IndicatorGroupResponse.  # noqa: E501
        :type: list[HierarchyChild]
        """

        self._hierarchy = hierarchy

    @property
    def id(self):
        """Gets the id of this IndicatorGroupResponse.  # noqa: E501


        :return: The id of this IndicatorGroupResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this IndicatorGroupResponse.


        :param id: The id of this IndicatorGroupResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this IndicatorGroupResponse.  # noqa: E501


        :return: The name of this IndicatorGroupResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this IndicatorGroupResponse.


        :param name: The name of this IndicatorGroupResponse.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def abbreviation(self):
        """Gets the abbreviation of this IndicatorGroupResponse.  # noqa: E501


        :return: The abbreviation of this IndicatorGroupResponse.  # noqa: E501
        :rtype: str
        """
        return self._abbreviation

    @abbreviation.setter
    def abbreviation(self, abbreviation):
        """Sets the abbreviation of this IndicatorGroupResponse.


        :param abbreviation: The abbreviation of this IndicatorGroupResponse.  # noqa: E501
        :type: str
        """

        self._abbreviation = abbreviation

    @property
    def active(self):
        """Gets the active of this IndicatorGroupResponse.  # noqa: E501


        :return: The active of this IndicatorGroupResponse.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this IndicatorGroupResponse.


        :param active: The active of this IndicatorGroupResponse.  # noqa: E501
        :type: bool
        """
        if active is None:
            raise ValueError("Invalid value for `active`, must not be `None`")  # noqa: E501

        self._active = active

    @property
    def is_paused(self):
        """Gets the is_paused of this IndicatorGroupResponse.  # noqa: E501


        :return: The is_paused of this IndicatorGroupResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_paused

    @is_paused.setter
    def is_paused(self, is_paused):
        """Sets the is_paused of this IndicatorGroupResponse.


        :param is_paused: The is_paused of this IndicatorGroupResponse.  # noqa: E501
        :type: bool
        """
        if is_paused is None:
            raise ValueError("Invalid value for `is_paused`, must not be `None`")  # noqa: E501

        self._is_paused = is_paused

    @property
    def is_snoozed(self):
        """Gets the is_snoozed of this IndicatorGroupResponse.  # noqa: E501


        :return: The is_snoozed of this IndicatorGroupResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_snoozed

    @is_snoozed.setter
    def is_snoozed(self, is_snoozed):
        """Sets the is_snoozed of this IndicatorGroupResponse.


        :param is_snoozed: The is_snoozed of this IndicatorGroupResponse.  # noqa: E501
        :type: bool
        """
        if is_snoozed is None:
            raise ValueError("Invalid value for `is_snoozed`, must not be `None`")  # noqa: E501

        self._is_snoozed = is_snoozed

    @property
    def created(self):
        """Gets the created of this IndicatorGroupResponse.  # noqa: E501


        :return: The created of this IndicatorGroupResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this IndicatorGroupResponse.


        :param created: The created of this IndicatorGroupResponse.  # noqa: E501
        :type: datetime
        """
        if created is None:
            raise ValueError("Invalid value for `created`, must not be `None`")  # noqa: E501

        self._created = created

    @property
    def corporation(self):
        """Gets the corporation of this IndicatorGroupResponse.  # noqa: E501


        :return: The corporation of this IndicatorGroupResponse.  # noqa: E501
        :rtype: CorporationChild
        """
        return self._corporation

    @corporation.setter
    def corporation(self, corporation):
        """Sets the corporation of this IndicatorGroupResponse.


        :param corporation: The corporation of this IndicatorGroupResponse.  # noqa: E501
        :type: CorporationChild
        """
        if corporation is None:
            raise ValueError("Invalid value for `corporation`, must not be `None`")  # noqa: E501

        self._corporation = corporation

    @property
    def location(self):
        """Gets the location of this IndicatorGroupResponse.  # noqa: E501


        :return: The location of this IndicatorGroupResponse.  # noqa: E501
        :rtype: LocationChild
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this IndicatorGroupResponse.


        :param location: The location of this IndicatorGroupResponse.  # noqa: E501
        :type: LocationChild
        """
        if location is None:
            raise ValueError("Invalid value for `location`, must not be `None`")  # noqa: E501

        self._location = location

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IndicatorGroupResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IndicatorGroupResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AssetCategoryChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'category_id': 'int',
        'category_name': 'str',
        'category_short_name': 'str',
        'category_code': 'str',
        'category_marker': 'AssetCategoryMarkerChild'
    }

    attribute_map = {
        'category_id': 'CategoryId',
        'category_name': 'CategoryName',
        'category_short_name': 'CategoryShortName',
        'category_code': 'CategoryCode',
        'category_marker': 'CategoryMarker'
    }

    def __init__(self, category_id=None, category_name=None, category_short_name=None, category_code=None, category_marker=None):  # noqa: E501
        """AssetCategoryChild - a model defined in Swagger"""  # noqa: E501
        self._category_id = None
        self._category_name = None
        self._category_short_name = None
        self._category_code = None
        self._category_marker = None
        self.discriminator = None
        self.category_id = category_id
        self.category_name = category_name
        if category_short_name is not None:
            self.category_short_name = category_short_name
        self.category_code = category_code
        if category_marker is not None:
            self.category_marker = category_marker

    @property
    def category_id(self):
        """Gets the category_id of this AssetCategoryChild.  # noqa: E501


        :return: The category_id of this AssetCategoryChild.  # noqa: E501
        :rtype: int
        """
        return self._category_id

    @category_id.setter
    def category_id(self, category_id):
        """Sets the category_id of this AssetCategoryChild.


        :param category_id: The category_id of this AssetCategoryChild.  # noqa: E501
        :type: int
        """
        if category_id is None:
            raise ValueError("Invalid value for `category_id`, must not be `None`")  # noqa: E501

        self._category_id = category_id

    @property
    def category_name(self):
        """Gets the category_name of this AssetCategoryChild.  # noqa: E501


        :return: The category_name of this AssetCategoryChild.  # noqa: E501
        :rtype: str
        """
        return self._category_name

    @category_name.setter
    def category_name(self, category_name):
        """Sets the category_name of this AssetCategoryChild.


        :param category_name: The category_name of this AssetCategoryChild.  # noqa: E501
        :type: str
        """
        if category_name is None:
            raise ValueError("Invalid value for `category_name`, must not be `None`")  # noqa: E501

        self._category_name = category_name

    @property
    def category_short_name(self):
        """Gets the category_short_name of this AssetCategoryChild.  # noqa: E501


        :return: The category_short_name of this AssetCategoryChild.  # noqa: E501
        :rtype: str
        """
        return self._category_short_name

    @category_short_name.setter
    def category_short_name(self, category_short_name):
        """Sets the category_short_name of this AssetCategoryChild.


        :param category_short_name: The category_short_name of this AssetCategoryChild.  # noqa: E501
        :type: str
        """

        self._category_short_name = category_short_name

    @property
    def category_code(self):
        """Gets the category_code of this AssetCategoryChild.  # noqa: E501


        :return: The category_code of this AssetCategoryChild.  # noqa: E501
        :rtype: str
        """
        return self._category_code

    @category_code.setter
    def category_code(self, category_code):
        """Sets the category_code of this AssetCategoryChild.


        :param category_code: The category_code of this AssetCategoryChild.  # noqa: E501
        :type: str
        """
        if category_code is None:
            raise ValueError("Invalid value for `category_code`, must not be `None`")  # noqa: E501

        self._category_code = category_code

    @property
    def category_marker(self):
        """Gets the category_marker of this AssetCategoryChild.  # noqa: E501


        :return: The category_marker of this AssetCategoryChild.  # noqa: E501
        :rtype: AssetCategoryMarkerChild
        """
        return self._category_marker

    @category_marker.setter
    def category_marker(self, category_marker):
        """Sets the category_marker of this AssetCategoryChild.


        :param category_marker: The category_marker of this AssetCategoryChild.  # noqa: E501
        :type: AssetCategoryMarkerChild
        """

        self._category_marker = category_marker

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AssetCategoryChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssetCategoryChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.nodes_api import NodesApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestNodesApi(unittest.TestCase):
    """NodesApi unit test stubs"""

    def setUp(self):
        self.api = NodesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_export_long_burst(self):
        """Test case for export_long_burst

        Gets a long burst export for a given node  # noqa: E501
        """
        pass

    def test_export_nodes(self):
        """Test case for export_nodes

        Requests Node export.  # noqa: E501
        """
        pass

    def test_get_node(self):
        """Test case for get_node

        Gets the requested node  # noqa: E501
        """
        pass

    def test_get_nodes(self):
        """Test case for get_nodes

        Gets a paginated list of the nodes to which a user has access  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.activity_events_api import ActivityEventsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestActivityEventsApi(unittest.TestCase):
    """ActivityEventsApi unit test stubs"""

    def setUp(self):
        self.api = ActivityEventsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_activity_event(self):
        """Test case for create_activity_event

        Create an activity event  # noqa: E501
        """
        pass

    def test_create_activity_event_category_relationship(self):
        """Test case for create_activity_event_category_relationship

        Create an activity event category relationship  # noqa: E501
        """
        pass

    def test_create_activity_event_relationship(self):
        """Test case for create_activity_event_relationship

        Create an activity event relationship  # noqa: E501
        """
        pass

    def test_delete_activity_event(self):
        """Test case for delete_activity_event

        Delete an activity event  # noqa: E501
        """
        pass

    def test_delete_activity_event_category_relationship(self):
        """Test case for delete_activity_event_category_relationship

        Delete an activity event category relationship  # noqa: E501
        """
        pass

    def test_delete_activity_event_relationship(self):
        """Test case for delete_activity_event_relationship

        Delete an activity event relationship  # noqa: E501
        """
        pass

    def test_get_activity_event(self):
        """Test case for get_activity_event

        Gets an activity event  # noqa: E501
        """
        pass

    def test_get_activity_event_categories(self):
        """Test case for get_activity_event_categories

        Gets activity event categories  # noqa: E501
        """
        pass

    def test_get_activity_event_category(self):
        """Test case for get_activity_event_category

        Gets an activity event category  # noqa: E501
        """
        pass

    def test_get_activity_event_category_fields(self):
        """Test case for get_activity_event_category_fields

        Get activity event category fields  # noqa: E501
        """
        pass

    def test_get_activity_event_category_relationship(self):
        """Test case for get_activity_event_category_relationship

        Gets an activity event category relationship  # noqa: E501
        """
        pass

    def test_get_activity_event_detail(self):
        """Test case for get_activity_event_detail

        Gets an activity event details. Expands on standard get activity event (by id) method  # noqa: E501
        """
        pass

    def test_get_activity_event_field_values(self):
        """Test case for get_activity_event_field_values

        Get activity event field values (if any)  # noqa: E501
        """
        pass

    def test_get_activity_event_relationship(self):
        """Test case for get_activity_event_relationship

        Gets an activity event relationship  # noqa: E501
        """
        pass

    def test_get_activity_event_subcategories(self):
        """Test case for get_activity_event_subcategories

        Get activity event subcategories  # noqa: E501
        """
        pass

    def test_get_activity_events(self):
        """Test case for get_activity_events

        Gets activity events  # noqa: E501
        """
        pass

    def test_get_hierarchy_activity_events_post(self):
        """Test case for get_hierarchy_activity_events_post

        Gets activity events for hierarchy groups  # noqa: E501
        """
        pass

    def test_update_activity_event(self):
        """Test case for update_activity_event

        Update an activity event  # noqa: E501
        """
        pass

    def test_update_activity_event_field_values(self):
        """Test case for update_activity_event_field_values

        Update / replace activity event field values list  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from smart_diagnostics_client.api_client import ApiClient


class BoardTicketStatusesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_status(self, **kwargs):  # noqa: E501
        """Creates a status  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_status(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BoardTicketStatusCreateRequest body:
        :return: StatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_status_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.create_status_with_http_info(**kwargs)  # noqa: E501
            return data

    def create_status_with_http_info(self, **kwargs):  # noqa: E501
        """Creates a status  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_status_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BoardTicketStatusCreateRequest body:
        :return: StatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_status" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/BoardTicketStatuses', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StatusResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_status(self, status_id, **kwargs):  # noqa: E501
        """Deletes the Status with the specified id.  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_status(status_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str status_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_status_with_http_info(status_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_status_with_http_info(status_id, **kwargs)  # noqa: E501
            return data

    def delete_status_with_http_info(self, status_id, **kwargs):  # noqa: E501
        """Deletes the Status with the specified id.  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_status_with_http_info(status_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str status_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['status_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'status_id' is set
        if ('status_id' not in params or
                params['status_id'] is None):
            raise ValueError("Missing the required parameter `status_id` when calling `delete_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'status_id' in params:
            path_params['statusId'] = params['status_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/BoardTicketStatuses/{statusId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_default_statuses(self, **kwargs):  # noqa: E501
        """Gets a list of the default statuses in arbitrary,  static order.    The ids specified on these StatusChildren are to allow easy differentiation on  the frontend. They do not represent anything stored in the db.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_default_statuses(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[StatusChild]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_default_statuses_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_default_statuses_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_default_statuses_with_http_info(self, **kwargs):  # noqa: E501
        """Gets a list of the default statuses in arbitrary,  static order.    The ids specified on these StatusChildren are to allow easy differentiation on  the frontend. They do not represent anything stored in the db.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_default_statuses_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[StatusChild]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_default_statuses" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/BoardTicketStatuses/defaultStatuses', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[StatusChild]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_status(self, status_id, **kwargs):  # noqa: E501
        """Gets a Status  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_status(status_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str status_id: (required)
        :return: StatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_status_with_http_info(status_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_status_with_http_info(status_id, **kwargs)  # noqa: E501
            return data

    def get_status_with_http_info(self, status_id, **kwargs):  # noqa: E501
        """Gets a Status  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_status_with_http_info(status_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str status_id: (required)
        :return: StatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['status_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'status_id' is set
        if ('status_id' not in params or
                params['status_id'] is None):
            raise ValueError("Missing the required parameter `status_id` when calling `get_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'status_id' in params:
            path_params['statusId'] = params['status_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/BoardTicketStatuses/{statusId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StatusResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_status(self, status_id, **kwargs):  # noqa: E501
        """Updates the status with the specified id  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_status(status_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str status_id: (required)
        :param BoardTicketStatusUpdateRequest body:
        :return: StatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_status_with_http_info(status_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_status_with_http_info(status_id, **kwargs)  # noqa: E501
            return data

    def update_status_with_http_info(self, status_id, **kwargs):  # noqa: E501
        """Updates the status with the specified id  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_status_with_http_info(status_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str status_id: (required)
        :param BoardTicketStatusUpdateRequest body:
        :return: StatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['status_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'status_id' is set
        if ('status_id' not in params or
                params['status_id'] is None):
            raise ValueError("Missing the required parameter `status_id` when calling `update_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'status_id' in params:
            path_params['statusId'] = params['status_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/BoardTicketStatuses/{statusId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StatusResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
